@@ -9,15 +9,21 @@ use crate::chancell::msg::{
 };
 use crate::chancell::CELL_DATA_LEN;
 use caret::caret_int;
+use derive_deftly::Deftly;
 use std::fmt::Write;
 use std::net::{IpAddr, Ipv4Addr};
 use tor_bytes::{EncodeError, EncodeResult, Error, Result};
 use tor_bytes::{Readable, Reader, Writeable, Writer};
 use tor_linkspec::EncodedLinkSpec;
 use tor_llcrypto::pk::rsa::RsaIdentity;
+use tor_memquota::{derive_deftly_template_HasMemoryCost, memory_cost_structural_copy};
 
 use bitflags::bitflags;
 
+#[cfg(feature = "conflux")]
+#[cfg_attr(docsrs, doc(cfg(feature = "conflux")))]
+pub use super::conflux::{ConfluxLink, ConfluxLinked, ConfluxLinkedAck, ConfluxSwitch};
+
 #[cfg(feature = "hs")]
 #[cfg_attr(docsrs, doc(cfg(feature = "hs")))]
 pub use super::hs::{
@@ -30,7 +36,8 @@ pub use super::udp::{ConnectUdp, ConnectedUdp, Datagram};
 
 crate::restrict::restricted_msg! {
 /// A single parsed relay message, sent or received along a circuit
-#[derive(Debug, Clone)]
+#[derive(Debug, Clone, Deftly)]
+#[derive_deftly(HasMemoryCost)]
 #[non_exhaustive]
 @omit_from "avoid_conflict_with_a_blanket_implementation"
 pub enum AnyRelayMsg : RelayMsg {
@@ -73,6 +80,18 @@ pub enum AnyRelayMsg : RelayMsg {
     /// UDP stream data
     [feature = "experimental-udp"]
     Datagram,
+    /// Link circuits together at the receiving endpoint
+    [feature = "conflux"]
+    ConfluxLink,
+    /// Confirm that the circuits were linked
+    [feature = "conflux"]
+    ConfluxLinked,
+    /// Acknowledge the linkage of the circuits, for RTT measurement.
+    [feature = "conflux"]
+    ConfluxLinkedAck,
+    /// Switch to another leg in an already linked circuit construction.
+    [feature = "conflux"]
+    ConfluxSwitch,
     /// Establish Introduction
     [feature = "hs"]
     EstablishIntro,
@@ -130,6 +149,7 @@ bitflags! {
         const IPV6_PREFERRED = (1<<2);
     }
 }
+memory_cost_structural_copy!(BeginFlags);
 impl From<u32> for BeginFlags {
     fn from(v: u32) -> Self {
         BeginFlags::from_bits_truncate(v)
@@ -173,7 +193,8 @@ impl From<IpVersionPreference> for BeginFlags {
 /// connection fails, the exit should send an End message.
 ///
 /// Clients should reject these messages.
-#[derive(Debug, Clone)]
+#[derive(Debug, Clone, Deftly)]
+#[derive_deftly(HasMemoryCost)]
 pub struct Begin {
     /// Ascii string describing target address
     addr: Vec<u8>,
@@ -281,7 +302,8 @@ impl Body for Begin {
 ///
 /// These messages hold between 1 and [Data::MAXLEN] bytes of data each;
 /// they are the most numerous messages on the Tor network.
-#[derive(Debug, Clone)]
+#[derive(Debug, Clone, Deftly)]
+#[derive_deftly(HasMemoryCost)]
 pub struct Data {
     /// Contents of the cell, to be sent on a specific stream
     ///
@@ -381,7 +403,8 @@ impl Body for Data {
 /// Note that End messages do not implement a true half-closed state,
 /// so after sending an End message each party needs to wait a while
 /// to be sure that the stream is completely dead.
-#[derive(Debug, Clone)]
+#[derive(Debug, Clone, Deftly)]
+#[derive_deftly(HasMemoryCost)]
 pub struct End {
     /// Reason for closing the stream
     reason: EndReason,
@@ -392,6 +415,8 @@ pub struct End {
 
 caret_int! {
     /// A declared reason for closing a stream
+    #[derive(Deftly)]
+    #[derive_deftly(HasMemoryCost)]
     pub struct EndReason(u8) {
         /// Closing a stream because of an unspecified reason.
         ///
@@ -545,7 +570,8 @@ impl From<EndReason> for std::io::ErrorKind {
 /// back to the client.
 ///
 /// Clients never send Connected messages.
-#[derive(Debug, Clone)]
+#[derive(Debug, Clone, Deftly)]
+#[derive_deftly(HasMemoryCost)]
 pub struct Connected {
     /// Resolved address and TTL (time to live) in seconds
     addr: Option<(IpAddr, u32)>,
@@ -616,7 +642,8 @@ impl Body for Connected {
 ///
 /// See [tor-spec.txt](https://spec.torproject.org/tor-spec) for more
 /// information; also see the source for `tor_proto::circuit::sendme`.
-#[derive(Debug, Clone)]
+#[derive(Debug, Clone, Deftly)]
+#[derive_deftly(HasMemoryCost)]
 pub struct Sendme {
     /// A tag value authenticating the previously received data.
     digest: Option<Vec<u8>>,
@@ -680,7 +707,8 @@ impl Body for Sendme {
 ///
 /// This format only handled IPv4 addresses, RSA identities, and the
 /// TAP handshake.  Modern Tor clients use Extend2 instead.
-#[derive(Debug, Clone)]
+#[derive(Debug, Clone, Deftly)]
+#[derive_deftly(HasMemoryCost)]
 pub struct Extend {
     /// Where to extend to (address)
     addr: Ipv4Addr,
@@ -729,7 +757,8 @@ impl Body for Extend {
 ///
 /// Like Extend, the Extended message was only designed for the TAP
 /// handshake.
-#[derive(Debug, Clone)]
+#[derive(Debug, Clone, Deftly)]
+#[derive_deftly(HasMemoryCost)]
 pub struct Extended {
     /// Contents of the handshake sent in response to the EXTEND
     handshake: Vec<u8>,
@@ -765,7 +794,8 @@ impl Body for Extended {
 /// Unlike Extend messages, Extend2 messages can encode any handshake
 /// type, and can describe relays in ways other than IPv4 addresses
 /// and RSA identities.
-#[derive(Debug, Clone)]
+#[derive(Debug, Clone, Deftly)]
+#[derive_deftly(HasMemoryCost)]
 pub struct Extend2 {
     /// A vector of "link specifiers"
     ///
@@ -843,7 +873,8 @@ impl Body for Extend2 {
 /// Extended2 messages are generated by the former last hop of a
 /// circuit, to tell the client that they have successfully completed
 /// a handshake on the client's behalf.
-#[derive(Debug, Clone)]
+#[derive(Debug, Clone, Deftly)]
+#[derive_deftly(HasMemoryCost)]
 pub struct Extended2 {
     /// Contents of the CREATED2 cell that the new final hop sent in
     /// response
@@ -886,7 +917,8 @@ impl Body for Extended2 {
 /// Destroy messages interchangeably.  Truncated was intended to be a
 /// "soft" Destroy, that would leave the unaffected parts of a circuit
 /// still usable.
-#[derive(Debug, Clone)]
+#[derive(Debug, Clone, Deftly)]
+#[derive_deftly(HasMemoryCost)]
 pub struct Truncated {
     /// Reason for which this circuit was truncated.
     reason: DestroyReason,
@@ -919,7 +951,8 @@ impl Body for Truncated {
 /// lookup _without_ connecting to the resulting address.  On success
 /// the exit responds with a Resolved message; on failure it responds
 /// with an End message.
-#[derive(Debug, Clone)]
+#[derive(Debug, Clone, Deftly)]
+#[derive_deftly(HasMemoryCost)]
 pub struct Resolve {
     /// Ascii-encoded address to resolve
     query: Vec<u8>,
@@ -969,7 +1002,8 @@ impl Body for Resolve {
 }
 
 /// Possible response to a DNS lookup
-#[derive(Debug, Clone, Eq, PartialEq)]
+#[derive(Debug, Clone, Eq, PartialEq, Deftly)]
+#[derive_deftly(HasMemoryCost)]
 #[non_exhaustive]
 pub enum ResolvedVal {
     /// We found an IP address
@@ -1080,7 +1114,8 @@ impl Writeable for ResolvedVal {
 ///
 /// The Resolved message contains a list of zero or more addresses,
 /// and their associated times-to-live in seconds.
-#[derive(Debug, Clone)]
+#[derive(Debug, Clone, Deftly)]
+#[derive_deftly(HasMemoryCost)]
 pub struct Resolved {
     /// List of addresses and their associated time-to-live values.
     answers: Vec<(ResolvedVal, u32)>,
@@ -1144,7 +1179,8 @@ impl Body for Resolved {
 /// A relay message that we didn't recognize
 ///
 /// NOTE: Clients should generally reject these.
-#[derive(Debug, Clone)]
+#[derive(Debug, Clone, Deftly)]
+#[derive_deftly(HasMemoryCost)]
 pub struct Unrecognized {
     /// Command that we didn't recognize
     cmd: RelayCmd,
@@ -1194,7 +1230,8 @@ macro_rules! empty_body {
        pub struct $name:ident {}
    } => {
        $(#[$meta])*
-       #[derive(Clone,Debug,Default)]
+       #[derive(Clone,Debug,Default,derive_deftly::Deftly)]
+       #[derive_deftly(tor_memquota::HasMemoryCost)]
        #[non_exhaustive]
        pub struct $name {}
        impl $crate::relaycell::msg::Body for $name {
@@ -1285,3 +1322,6 @@ msg_impl_relaymsg!(
     RendezvousEstablished,
     IntroduceAck,
 );
+
+#[cfg(feature = "conflux")]
+msg_impl_relaymsg!(ConfluxSwitch);
