@@ -152,14 +152,21 @@ impl<'a> From<&'a NetDir> for DirInfo<'a> {
 }
 impl<'a> DirInfo<'a> {
     /// Return a set of circuit parameters for this DirInfo.
-    fn circ_params(&self) -> CircParameters {
-        use crate::build::circparameters_from_netparameters;
+    fn circ_params(&self, usage: &TargetCircUsage) -> Result<CircParameters> {
         use tor_netdir::params::NetParameters;
         // We use a common function for both cases here to be sure that
         // we look at the defaults from NetParameters code.
-        match self {
-            DirInfo::Directory(d) => circparameters_from_netparameters(d.params()),
-            _ => circparameters_from_netparameters(&NetParameters::default()),
+        let defaults = NetParameters::default();
+        let net_params = match self {
+            DirInfo::Directory(d) => d.params(),
+            _ => &defaults,
+        };
+        match usage {
+            #[cfg(feature = "hs-common")]
+            TargetCircUsage::HsCircBase { .. } => {
+                build::onion_circparams_from_netparams(net_params)
+            }
+            _ => build::exit_circparams_from_netparams(net_params),
         }
     }
 }
@@ -1113,9 +1120,8 @@ mod test {
         let fb = FallbackList::from([]);
         let di: DirInfo<'_> = (&fb).into();
 
-        let p1 = di.circ_params();
-        assert!(!p1.extend_by_ed25519_id());
-        assert_eq!(p1.initial_send_window(), 1000);
+        let p1 = di.circ_params(&TargetCircUsage::Dir).unwrap();
+        assert!(!p1.extend_by_ed25519_id);
 
         // Now try with a directory and configured parameters.
         let (consensus, microdescs) = tor_netdir::testnet::construct_network().unwrap();
@@ -1128,9 +1134,8 @@ mod test {
         }
         let netdir = dir.unwrap_if_sufficient().unwrap();
         let di: DirInfo<'_> = (&netdir).into();
-        let p2 = di.circ_params();
-        assert_eq!(p2.initial_send_window(), 100);
-        assert!(p2.extend_by_ed25519_id());
+        let p2 = di.circ_params(&TargetCircUsage::Dir).unwrap();
+        assert!(p2.extend_by_ed25519_id);
 
         // Now try with a bogus circwindow value.
         let (consensus, microdescs) = tor_netdir::testnet::construct_network().unwrap();
@@ -1143,9 +1148,8 @@ mod test {
         }
         let netdir = dir.unwrap_if_sufficient().unwrap();
         let di: DirInfo<'_> = (&netdir).into();
-        let p2 = di.circ_params();
-        assert_eq!(p2.initial_send_window(), 1000); // Not 100_000
-        assert!(p2.extend_by_ed25519_id());
+        let p2 = di.circ_params(&TargetCircUsage::Dir).unwrap();
+        assert!(p2.extend_by_ed25519_id);
     }
 
     fn make_circmgr<R: Runtime>(runtime: R) -> Arc<CircMgrInner<FakeBuilder<R>, R>> {
