@@ -465,7 +465,7 @@ impl Ipt {
         };
 
         // TODO #1186 Support ephemeral services (without persistent replay log)
-        let replay_log = ReplayLog::new_logged(&imm.replay_log_dir, &lid)?;
+        let replay_log = IptReplayLog::new_logged(&imm.replay_log_dir, &lid)?;
 
         let params = IptParameters {
             replay_log,
@@ -1384,9 +1384,12 @@ impl<R: Runtime, M: Mockable<R>> IptManager<R, M> {
             let ent = ent.map_err(handle_rl_err("read dir", replay_logs))?;
             let leaf = ent.file_name();
             // Try to identify this replay logfile (including its IptLocalId)
-            match ReplayLog::parse_log_leafname(&leaf) {
-                Ok((lid, _)) if all_ipts.contains(&lid) => continue,
-                Ok((_lid, leaf)) => trace!("deleting replay log for old IPT: {leaf}"),
+            match IptReplayLog::parse_log_leafname(&leaf) {
+                Ok(lid) if all_ipts.contains(&lid) => continue,
+                Ok(_) => trace!(
+                    leaf = leaf.to_string_lossy().as_ref(),
+                    "deleting replay log for old IPT"
+                ),
                 Err(bad) => info!(
                     "deleting garbage in IPT replay log dir: {} ({})",
                     leaf.to_string_lossy(),
