@@ -177,6 +177,11 @@ pub(crate) mod net {
         fn set_tcp_notsent_lowat(&self, notsent_lowat: u32) -> IoResult<()> {
             impls::streamops::set_tcp_notsent_lowat(&self.s, notsent_lowat)
         }
+
+        #[cfg(target_os = "linux")]
+        fn new_handle(&self) -> Box<dyn traits::StreamOps + Send + Unpin> {
+            Box::new(impls::streamops::TcpSockFd::from_fd(&self.s))
+        }
     }
 
     #[cfg(unix)]
@@ -331,6 +336,19 @@ impl BlockOn for TokioRuntimeHandle {
     }
 }
 
+impl SpawnBlocking for TokioRuntimeHandle {
+    type Handle<T: Send + 'static> = async_executors::BlockingHandle<T>;
+
+    #[track_caller]
+    fn spawn_blocking<F, T>(&self, f: F) -> async_executors::BlockingHandle<T>
+    where
+        F: FnOnce() -> T + Send + 'static,
+        T: Send + 'static,
+    {
+        async_executors::BlockingHandle::tokio(self.handle.spawn_blocking(f))
+    }
+}
+
 impl futures::task::Spawn for TokioRuntimeHandle {
     #[track_caller]
     fn spawn_obj(
