@@ -16,6 +16,19 @@ macro_rules! implement_opaque_runtime {
         }
     }
 
+    impl $crate::traits::SpawnBlocking for $t {
+        type Handle<T: Send + 'static> = <$mty as $crate::traits::SpawnBlocking>::Handle<T>;
+
+        #[inline]
+        fn spawn_blocking<F, T>(&self, f: F) -> <$mty as $crate::traits::SpawnBlocking>::Handle<T>
+        where
+            F: FnOnce() -> T + Send + 'static,
+            T: Send + 'static,
+        {
+            self.$member.spawn_blocking(f)
+        }
+    }
+
     impl $crate::traits::BlockOn for $t {
         #[inline]
         fn block_on<F: futures::Future>(&self, future: F) -> F::Output {
@@ -67,7 +80,7 @@ macro_rules! implement_opaque_runtime {
     }
 
     impl<S> $crate::traits::TlsProvider<S> for $t
-    where S: futures::AsyncRead + futures::AsyncWrite + Unpin + Send + 'static,
+    where S: futures::AsyncRead + futures::AsyncWrite + $crate::traits::StreamOps + Unpin + Send + 'static,
     {
         type Connector = <$mty as $crate::traits::TlsProvider<S>>::Connector;
         type TlsStream = <$mty as $crate::traits::TlsProvider<S>>::TlsStream;
